<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 08/25/2003 *
 * ===================                          Last change: 07/01/2005 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : modules.php                                      *
 * -------------------------------------------------------------------- *
 * Short description : Main loader file. Loads our needed stuff         *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Hauptladedatei. Laedt alle benoetigten Dateien   *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009, 2010 by Mailer Developer Team                    *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// XDEBUG call
//* DEBUG: */ xdebug_start_trace();

// Load security stuff here
require('inc/libs/security_functions.php');

// Init start time
$GLOBALS['startTime'] = microtime(true);

// Init output mode and module
$GLOBALS['output_mode'] = '0';
$GLOBALS['module'] = 'unknown';

// Needed include files
require('inc/config-global.php');

// Set content type
setContentType('text/html');

// The header file
loadIncludeOnce('inc/header.php');

// Modules are by default not valid!
$isModuleValid = false;
$URL = '';
$check = 'failed';

// Is the maintenance mode active or goes all well?
if ((isExtensionActive('maintenance')) && (getConfig('maintenance') == 'Y') && (!isAdmin()) && (getModule() != 'admin')) {
	// Maintain mode is active and you are no admin
	addFatalMessage(__FILE__, __LINE__, '{--MAILER_DOWN_FOR_MAINTENANCE--}');
} elseif ((SQL_IS_LINK_UP()) && (!ifFatalErrorsDetected())) {
	// Construct module name
	$GLOBALS['module_inc'] =  sprintf("inc/modules/%s.php", getModule());

	// Check module permission (again)
	$check = checkModulePermissions();
	switch ($check) {
		case 'cache_miss': // The cache is gone
		case 'admin_only': // Admin-only access
		case 'mem_only': // Member-only access
		case 'done': // All fine!
			// Does the module exists on local file system?
			if ((isIncludeReadable($GLOBALS['module_inc'])) && (!ifFatalErrorsDetected())) {
				// Module is valid, active and located on the local disc...
				$isModuleValid = true;
			} elseif (!ifFatalErrorsDetected()) {
				// Set HTTP status
				setHttpStatus('404');

				// Module not found!
				addFatalMessage(__FILE__, __LINE__, getMaskedMessage('MODULE_REGISTRY_404', getModule()));

				// Set module to error module (non-existent!)
				setModule('error');
			}
			break;

		case '404':
			// Set HTTP status
			setHttpStatus('404');

			// Add fatal message
			addFatalMessage(__FILE__, __LINE__, getMaskedMessage('MODULE_REGISTRY_404', getModule()));
			break;

		case 'locked':
			// Set HTTP status
			setHttpStatus('403');

			if (!isIncludeReadable($GLOBALS['module_inc'])) {
				// Set HTTP status
				setHttpStatus('404');

				// Module does addionally not exists
				addFatalMessage(__FILE__, __LINE__, getMaskedMessage('MODULE_REGISTRY_404', getModule()));
			} // END - if

			// Add fatal message
			addFatalMessage(__FILE__, __LINE__, getMaskedMessage('MODULE_IS_LOCKED', getModule()));
			break;

		default:
			// Unknown module status
			logDebugMessage(__FILE__, __LINE__, sprintf("Unknown status %s return from module check. Module=%s", $check, getModule()));
			addFatalMessage(__FILE__, __LINE__, getMaskedMessage('UNKNOWN_MODULE_STATUS', $check));
			break;
	} // END - switch
} elseif (!ifFatalErrorsDetected()) {
	// MySQL problems detected
	addFatalMessage(__FILE__, __LINE__, '{--MYSQL_ERRORS--}');
}

if (($isModuleValid === true) && (isset($GLOBALS['module_inc']))) {
	// Everything is okay so we can load the module
	loadIncludeOnce($GLOBALS['module_inc']);
} // END - if

// Add the footer (this will call shutdown())
loadIncludeOnce('inc/footer.php');

// [EOF]
?>
